@@ -96,7 +96,7 @@ class AntiddosClient(AbstractClient):
 
 
     def CreateBoundIP(self, request):
-        """绑定IP到高防包实例，支持独享包、共享包；需要注意的是此接口绑定或解绑IP是异步接口，当处于绑定或解绑中时，则不允许再进行绑定或解绑，需要等待当前绑定或解绑完成。
+        """绑定IP到高防包实例，支持独享包、共享包（新版）；需要注意的是此接口绑定或解绑IP是异步接口，当处于绑定或解绑中时，则不允许再进行绑定或解绑，需要等待当前绑定或解绑完成。
 
         :param request: Request instance for CreateBoundIP.
         :type request: :class:`tencentcloud.antiddos.v20200309.models.CreateBoundIPRequest`
@@ -188,7 +188,7 @@ class AntiddosClient(AbstractClient):
 
 
     def CreateCcGeoIPBlockConfig(self, request):
-        """新建cc防护的地域封禁配置
+        """新建CC防护的地域封禁配置
 
         :param request: Request instance for CreateCcGeoIPBlockConfig.
         :type request: :class:`tencentcloud.antiddos.v20200309.models.CreateCcGeoIPBlockConfigRequest`
@@ -877,6 +877,29 @@ class AntiddosClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeBGPIPL7Rules(self, request):
+        """高防IP获取7层规则
+
+        :param request: Request instance for DescribeBGPIPL7Rules.
+        :type request: :class:`tencentcloud.antiddos.v20200309.models.DescribeBGPIPL7RulesRequest`
+        :rtype: :class:`tencentcloud.antiddos.v20200309.models.DescribeBGPIPL7RulesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeBGPIPL7Rules", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeBGPIPL7RulesResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeBasicDeviceStatus(self, request):
         """获取基础防护攻击状态
 
@@ -993,7 +1016,9 @@ class AntiddosClient(AbstractClient):
 
 
     def DescribeBlackWhiteIpList(self, request):
-        """获取DDoS防护的IP黑白名单
+        """接口变更
+
+        获取DDoS防护的IP黑白名单
 
         :param request: Request instance for DescribeBlackWhiteIpList.
         :type request: :class:`tencentcloud.antiddos.v20200309.models.DescribeBlackWhiteIpListRequest`
@@ -1291,6 +1316,29 @@ class AntiddosClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeIpBlockList(self, request):
+        """获取IP封堵列表
+
+        :param request: Request instance for DescribeIpBlockList.
+        :type request: :class:`tencentcloud.antiddos.v20200309.models.DescribeIpBlockListRequest`
+        :rtype: :class:`tencentcloud.antiddos.v20200309.models.DescribeIpBlockListResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeIpBlockList", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeIpBlockListResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeL7RulesBySSLCertId(self, request):
         """查询与证书ID对于域名匹配的七层规则
 
@@ -1545,7 +1593,9 @@ class AntiddosClient(AbstractClient):
 
 
     def DescribeListProtectThresholdConfig(self, request):
-        """获取防护阈值配置列表，包括DDoS的AI、等级、CC阈值开关等
+        """接口变更
+
+        获取防护阈值配置列表，包括DDoS的AI、等级、CC阈值开关等
 
         :param request: Request instance for DescribeListProtectThresholdConfig.
         :type request: :class:`tencentcloud.antiddos.v20200309.models.DescribeListProtectThresholdConfigRequest`
